========
Contents
========

.. toctree::
   :maxdepth: 2

   readme
   installation
   design
   contributing
   authors

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
